@@ -8,7 +8,7 @@ $(document).ready(function(){
         $("#nav_left").append('<li id="new_feature_btn" class="sub_items"><a>New</a></li>');
         $("#navbar").before('<div id="new_feature_content"><div><span class="content">${content}</span><span class="close">x</span><div></div>')
         $("#new_feature_btn").bind("click", function(){
-            $("#new_feature_content").slideDown();
+            $("#new_feature_content").slideToggle();
         });
         $("#new_feature_content .close").bind("click", function(){
             $("#new_feature_content").slideUp();
